Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
.tox/cov/lib/python3.11/site-packages/confattr/__init__.py | 8 | 0 | 2 | 0 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/config.py | 189 | 0 | 21 | 76 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/configfile.py | 1220 | 0 | 38 | 554 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/formatters.py | 333 | 0 | 30 | 166 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/subprocess_pipe.py | 32 | 0 | 0 | 6 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/types.py | 135 | 0 | 7 | 64 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/utils.py | 108 | 0 | 11 | 24 | 0 | 100%
Total | 2025 | 0 | 109 | 890 | 0 | 100%

No items found using the specified filter.